/*
 * Copyright (c) 2014 UPLEX - Nils Goroll Systemoptimierung
 * All rights reserved.
 * Use only with permission
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
 * TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
 * PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL AUTHOR OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 */

#include "dcs_config.h"

#include <errno.h>

#include "dcs_classifier.h"
#include "dcs_type.h"
	    
#define check_type_id(type_id, ret)					\
	do {								\
		if ((type_id < 0) || (type_id > (DCS_TYPE_COUNT - 1))) { \
			errno = EINVAL;					\
			return (ret);					\
		}							\
	} while(0)

const char *
dcs_type_name(int type_id /* enum dcs_type */) {
	check_type_id(type_id, 0);
	return dcs_type[type_id];
}

/*
 * useful meta-classification to just three string constants:
 *
 * 
 *
 *
 */
enum dcs_type_mtd {
	T_MTD_MISSING = 0,
	T_MTD_MOB,
	T_MTD_TAB,
	T_MTD_DSK
#define T_MTD_MAX T_MTD_DSK
};

const char * const dsc_type_mtd_str[T_MTD_MAX + 1] = {
	[T_MTD_MISSING]	= "dsk",
	[T_MTD_MOB]	= "mob",
	[T_MTD_TAB]	= "tab",
	[T_MTD_DSK]	= "dsk"
};
	
enum dcs_type dcs_type2mtd[DCS_TYPE_COUNT] = {
	[NB_T_UNIDENTIFIED]		= T_MTD_DSK,
	[NB_T_BOT]			= T_MTD_DSK,
	[NB_T_CAMERA]			= T_MTD_MOB,
	[NB_T_CE_DEVICE]		= T_MTD_MOB,	// android 1.5; en-us; nimble
	[NB_T_COMPUTER]			= T_MTD_DSK,	// macintosh*intel*mac os
	[NB_T_DESKTOP_BROWSER]		= T_MTD_DSK,
	[NB_T_DEVTOOL]			= T_MTD_DSK,
	[NB_T_EREADER]			= T_MTD_TAB,
	[NB_T_MEDIAPLAYER]		= T_MTD_MOB,
	[NB_T_MOBILECONSOLE]		= T_MTD_MOB,
	[NB_T_MOBILE_BROWSER]		= T_MTD_MOB,
	[NB_T_MOBILE_PHONE]		= T_MTD_MOB,
	[NB_T_OPERATINGSYSTEM]		= T_MTD_MOB,	// ios 4.2
	[NB_T_SETTOP_BOX_TV]		= T_MTD_DSK,
	[NB_T_TABLET]			= T_MTD_TAB,
	[NB_T_WEARABLE_COMPUTER] 	= T_MTD_MOB	// android 4.0*glass
};

const char *
dcs_type_mtd(int type_id /* enum dcs_type */) {
	check_type_id(type_id, 0);
	return (dsc_type_mtd_str[dcs_type2mtd[type_id]]);
}
